@@ -23,15 +23,21 @@ MAKE_FILE_BACKUPS = False
 gpu_client = GpuInfo()
 
 try:
-  for gpu in gpu_client.getGpuInfo():
-    gpu_name = gpu[0]
-    gpu_free_memory = gpu[1]
-    gpu_load = gpu[2]
+  if gpu_client.getGpuCount() > 0:
+    for gpu in gpu_client.getGpuInfo():
+      gpu_name = gpu[0]
+      gpu_free_memory = gpu[1]
+      gpu_load = gpu[2]
 except ZoeException:
   logger.exception("An error occurred while getting GPU info")
-  gpu_name = "Unknown"
-  gpu_free_memory = "Unknown"
-  gpu_load = "Unknown"
+  gpu_name = None
+  gpu_free_memory = None
+  gpu_load = None
+except NameError:
+  logger.exception("An error occurred while getting GPU info")
+  gpu_name = None
+  gpu_free_memory = None
+  gpu_load = None
 
 class Runtime():
   buildId: str = None # the build number of the current execution
